@@ -1,7 +1,7 @@
 #
 # crossdistlpp.R
 #
-#  $Revision: 1.2 $ $Date: 2012/10/13 03:22:28 $
+#  $Revision: 1.3 $ $Date: 2013/08/23 07:35:36 $
 #
 #  crossdist.lpp
 #        Calculates the shortest-path distance from each point of X
@@ -83,6 +83,7 @@ crossdist.lpp <- function(X, Y, ..., method="C") {
     to0   <- to - 1L
     Xsegmap <- Xpro - 1L
     Ysegmap <- Ypro - 1L
+    DUP <- spatstat.options("dupC")
     zz <- .C("lincrossdist",
              np = as.integer(nX),
              xp = as.double(P$x),
@@ -100,7 +101,8 @@ crossdist.lpp <- function(X, Y, ..., method="C") {
              psegmap = as.integer(Xsegmap),
              qsegmap = as.integer(Ysegmap),
              answer = as.double(crossdistmat),
-             PACKAGE="spatstat")
+             DUP=DUP)
+#             PACKAGE="spatstat")
     crossdistmat <- matrix(zz$answer, nX, nY)
   }
   return(crossdistmat)
