@@ -2,7 +2,7 @@
 #   nncross.R
 #
 #
-#    $Revision: 1.25 $  $Date: 2013/11/03 02:42:48 $
+#    $Revision: 1.26 $  $Date: 2013/12/11 08:42:46 $
 #
 #  Copyright (C) Adrian Baddeley, Jens Oehlschlaegel and Rolf Turner 2000-2012
 #  Licence: GNU Public Licence >= 2
@@ -12,7 +12,7 @@ nncross <- function(X, Y, ...) {
 }
 
 nncross.default <- function(X, Y, ...) {
-  X <- as.ppp(X, W=bounding.box.xy)
+  X <- as.ppp(X, W=boundingbox)
   nncross(X, Y, ...)
 }
 
@@ -132,7 +132,7 @@ nncross.ppp <- function(X, Y, iX=NULL, iY=NULL,
     if(!exclude) iX <- iY <- integer(1)
 
     DUP <- spatstat.options("dupC")
-    huge <- 1.1 * diameter(bounding.box(as.rectangle(X), as.rectangle(Y)))
+    huge <- 1.1 * diameter(boundingbox(as.rectangle(X), as.rectangle(Y)))
 
     z <- .C("nnXinterface",
             n1=as.integer(nX),
@@ -179,7 +179,7 @@ nncross.ppp <- function(X, Y, iX=NULL, iY=NULL,
     if(!exclude) iX <- iY <- integer(1)
 
     DUP <- spatstat.options("dupC")
-    huge <- 1.1 * diameter(bounding.box(as.rectangle(X), as.rectangle(Y)))
+    huge <- 1.1 * diameter(boundingbox(as.rectangle(X), as.rectangle(Y)))
   
     z <- .C("knnXinterface",
             n1=as.integer(nX),
@@ -235,6 +235,8 @@ nncross.ppp <- function(X, Y, iX=NULL, iY=NULL,
     }
 
     result <- as.data.frame(list(dist=NND, which=NNW)[what])
+    colnames(result) <- c(if(want.dist) paste0("dist.", k) else NULL,
+                          if(want.which) paste0("which.",k) else NULL)
     if(ncol(result) == 1)
       result <- result[, , drop=TRUE]
     return(result)
