@@ -4,7 +4,7 @@
 #	A class 'ppp' to define point patterns
 #	observed in arbitrary windows in two dimensions.
 #
-#	$Revision: 4.89 $	$Date: 2014/02/07 08:58:53 $
+#	$Revision: 4.96 $	$Date: 2014/02/27 06:32:02 $
 #
 #	A point pattern contains the following entries:	
 #
@@ -65,8 +65,8 @@ ppp <- function(x, y, ..., window, marks, check=TRUE, drop=TRUE) {
                     ngettext(nout, "point was", "points were"),
                     "rejected as lying outside the specified window"))
       rr <- ripras(x,y)
-      bb <- bounding.box.xy(x,y)
-      bb <- bounding.box(rr, bb, window)
+      bb <- boundingbox(x,y)
+      bb <- boundingbox(rr, bb, window)
       rejectwindow <-
         if(!is.null(rr)) rebound.owin(rr, bb) else bb
       rejects <- ppp(x[!ok], y[!ok], window=rejectwindow, check=FALSE)
@@ -110,9 +110,11 @@ ppp <- function(x, y, ..., window, marks, check=TRUE, drop=TRUE) {
   } else {
     # should be a vector or factor
     # To recognise vector, strip attributes
-    if(!is.factor(marks))
+    isspecial <- is.factor(marks) ||
+                 inherits(marks, "POSIXt") || inherits(marks, "Date")
+    if(!isspecial)
       attributes(marks) <- NULL
-    if(!(is.vector(marks) || is.factor(marks)))
+    if(!(is.vector(marks) || isspecial))
       stop("Format of marks not understood")
     # OK, it's a vector or factor
     pp$markformat <- "vector"
@@ -402,11 +404,11 @@ print.ppp <- local({
   print.ppp <- function(x, ...) {
     verifyclass(x, "ppp")
     ism <- is.marked(x, dfok=TRUE)
-    cat(paste(if(ism) "marked" else NULL,
-              "planar point pattern:",
-              x$n,
-              ngettext(x$n, "point", "points"),
-              "\n"))
+    cat(paste0(if(ism) "marked " else NULL,
+               "planar point pattern:"),
+        x$n,
+        ngettext(x$n, "point", "points"),
+        fill=TRUE)
     if(ism) {
       mks <- marks(x, dfok=TRUE)
       if(is.data.frame(mks)) {
@@ -419,30 +421,36 @@ print.ppp <- local({
         } else {
           ## Numeric, or could be dates
           if(inherits(mks, "Date")) {
-            desc <- paste("dates, of class", sQuote("Date"))
+            cat("marks are dates,",
+                "of class", sQuote("Date"),
+                fill=TRUE)
           } else if(inherits(mks, "POSIXt")) {
-            desc <- paste("dates, of class", sQuote("POSIXt"))
+            cat("marks are dates,",
+                "of class", sQuote("POSIXt"),
+                fill=TRUE)
           } else {
-            desc <- paste0(if(is.numeric(mks)) "numeric, ",
-                           "of storage type ", sQuote(typeof(mks)))
-            styp <- typeof(mks)
+            cat(paste0("marks are", if(is.numeric(mks)) " numeric," else NULL),
+                "of storage type ", sQuote(typeof(mks)),
+                fill=TRUE)
           }
-          cat(paste("marks are", desc, "\n"))
         }
       }
     }
     print(x$window)
     if(!is.null(rejects <- attr(x, "rejects"))) {
       nrejects <- rejects$n
-      cat(paste("\n***",
-                nrejects,
-                ngettext(nrejects, "illegal point", "illegal points"),
-                "stored in",
-                paste("attr(,", dQuote("rejects"), ")", sep=""),
-                "***\n"))
+      cat("***",
+          nrejects,
+          ngettext(nrejects, "illegal point", "illegal points"),
+          "stored in",
+          paste("attr(,", dQuote("rejects"), ")", sep=""),
+          "***",
+          fill=TRUE)
     }
     if(!is.null(info <- attr(x, "info")) && inherits(info, "rmhInfoList"))
-      cat("\nPattern was generated by Metropolis-Hastings simulation.\n")
+      cat("\nPattern was generated by",
+          "Metropolis-Hastings simulation.",
+          fill=TRUE)
     return(invisible(NULL))
   }
 
@@ -494,53 +502,63 @@ summary.ppp <- function(object, ..., checkdup=TRUE) {
 
 print.summary.ppp <- function(x, ..., dp=3) {
   verifyclass(x, "summary.ppp")
-  cat(paste(if(x$is.marked) "Marked planar " else "Planar ",
-            "point pattern: ",
-            x$n,
-            " points\n",
-            sep=""))
+  cat(if(x$is.marked) "Marked planar" else "Planar",
+      "point pattern: ",
+      x$n,
+      "points",
+      fill=TRUE)
   oneline <- resolve.defaults(list(...), list(oneline=FALSE))$oneline
   if(oneline) return(invisible(NULL))
   unitinfo <- summary(x$window$units)
-  cat(paste("Average intensity",
-            signif(x$intensity,dp),
-            "points per square",
-            unitinfo$singular,
-            unitinfo$explain,
-            "\n"))
+  cat("Average intensity",
+      signif(x$intensity,dp),
+      "points per square",
+      unitinfo$singular,
+      unitinfo$explain,
+      fill=TRUE)
   ndup <- x$nduplicated
   if((!is.null(ndup)) && (ndup > 0))
-    cat("\n*Pattern contains duplicated points*\n")
+    cat("\n*Pattern contains", "duplicated points*", fill=TRUE)
   rndg <- x$rounding
   if(!is.null(rndg)) {
-    if(rndg >= 4) {
-      cat(paste("\nCoordinates are given to", rndg, "decimal places\n"))
-    } else if(rndg > 0) {
-      cat(paste("\nCoordinates are given to", rndg, "decimal places",
-                "\ni.e. rounded to the nearest multiple of",
-                10^(-rndg), unitinfo$plural, unitinfo$explain, "\n"))
+    cat("\n")
+    if(rndg >= 1) {
+      cat("Coordinates are", "given to",
+          rndg,
+          "decimal", ngettext(rndg, "place", "places"),
+          fill=TRUE)
+      if(rndg <= 3) {
+        cat("i.e. rounded to", "the nearest", "multiple of",
+            10^(-rndg), unitinfo$plural, unitinfo$explain,
+            fill=TRUE)
+      }
     } else if(rndg == 0) {
-      cat(paste("\nCoordinates are integers",
-                "\ni.e. rounded to the nearest 1", unitinfo$singular,
-                unitinfo$explain, "\n"))
+      cat("Coordinates are", "integers", fill=TRUE)
+      cat("i.e. rounded to", "the nearest", unitinfo$singular,
+          unitinfo$explain, 
+          fill=TRUE)
     } else {
-      cat(paste("\nCoordinates are multiples of", 10^(-rndg), unitinfo$plural,
-                unitinfo$explain, "\n"))
+      cat("Coordinates are", "multiples of",
+          10^(-rndg), unitinfo$plural, unitinfo$explain, 
+          fill=TRUE)
     }
     cat("\n")
   }
   if(x$is.marked) {
     if(x$multiple.marks) {
-      cat(paste("Mark variables: ", paste(x$marknames, collapse=", "), "\n"))
+      mn <- x$marknames
+      mn <- commasep(mn, ", ", flatten=FALSE)
+      cat("Mark variables:", mn, fill=TRUE)
       cat("Summary:\n")
       print(x$marks)
     } else if(x$is.multitype) {
       cat("Multitype:\n")
       print(signif(x$marks,dp))
     } else {
-      cat(paste("marks are ",
-                if(x$is.numeric) "numeric, ",
-                "of type", sQuote(x$marktype), "\n"))
+      cat("marks are ",
+          if(x$is.numeric) "numeric, ",
+          "of type", sQuote(x$marktype), 
+          fill=TRUE)
       cat("Summary:\n")
       print(x$marks)
     }
@@ -548,14 +566,17 @@ print.summary.ppp <- function(x, ..., dp=3) {
   }
   print(x$window)
   if(!is.null(nrejects <- x$rejects)) 
-    cat(paste("\n***",
-              nrejects,
-              ngettext(nrejects, "illegal point", "illegal points"),
-              "stored in",
-              paste("attr(,", dQuote("rejects"), ")", sep=""),
-              "***\n"))
+    cat("\n***",
+        nrejects,
+        ngettext(nrejects, "illegal point", "illegal points"),
+        "stored in",
+        paste("attr(,", dQuote("rejects"), ")", sep=""),
+        "***",
+        fill=TRUE)
   if(!is.null(info <- x$rmhinfo)) {
-    cat("\nPattern was generated by Metropolis-Hastings algorithm rmh")
+    cat("\nPattern was generated by",
+        "Metropolis-Hastings algorithm rmh",
+        fill=TRUE)
     print(info)
   }
   return(invisible(x))
@@ -565,16 +586,12 @@ print.summary.ppp <- function(x, ..., dp=3) {
 
 identify.ppp <- function(x, ...) {
   verifyclass(x, "ppp")
-  if(!is.marked(x) || "labels" %in% names(list(...)))
-    identify(x$x, x$y, ...)
-  else {
-    marx <- marks(x, dfok=FALSE)
-    marques <- if(is.numeric(marx)) paste(signif(marx, 3)) else paste(marx)
-    id <- identify(x$x, x$y, labels=marques, ...)
-    mk <- marx[id]
-    if(is.factor(marx)) mk <- levels(marx)[mk]
-    cbind(id=id, marks=mk)
-  }
+  id <- identify(x$x, x$y, ...)
+  if(!is.marked(x)) return(id)
+  marks <- as.data.frame(x)[id, -(1:2)]
+  out <- cbind(data.frame(id=id), marks)
+  row.names(out) <- NULL
+  return(out)
 }
 
 rebound <- function(x, rect) {
