@@ -1,12 +1,21 @@
 #
 #  smoothfv.R
 #
-#   $Revision: 1.8 $   $Date: 2013/08/05 07:08:51 $
+#   $Revision: 1.13 $   $Date: 2014/01/15 10:03:35 $
 #
   
 smooth.fv <- function(x, which="*", ..., 
                       method=c("smooth.spline", "loess"),
                       xinterval=NULL) {
+  .Deprecated("Smooth.fv", package="spatstat",
+     msg="smooth.fv is deprecated: use the generic Smooth with a capital S")
+  Smooth(x, which=which, ..., method=method, xinterval=xinterval)
+}
+  
+Smooth.fv <- function(X, which="*", ..., 
+                      method=c("smooth.spline", "loess"),
+                      xinterval=NULL) {
+  x <- X
   stopifnot(is.character(which))
   method <- match.arg(method)
   if(!is.null(xinterval))
